%define shortVersion %(echo %{version} | cut -d. -f1,2)
%define majorVersion %(echo %{version} | cut -d. -f1)

%bcond_with bootstrap

%bcond_without qt
%bcond_with tests

#comment out if not prerel
#define prerel rc3

#release for bumping
%define rel 2

Name:		cmake
Summary:	Cross-platform, open-source make system
Epoch:		1
Version:	3.19.2
Release:	%mkrel %{?prerel:0.%prerel.}%{rel}
License:	BSD
Group:		Development/Other
Url:		https://www.cmake.org/
Source0:	https://www.cmake.org/files/v%{shortVersion}/%{name}-%{version}%{?prerel:-%prerel}.tar.gz
Patch1:		0001-FindGTK2-when-searching-atkmm-includes-search-also-a.patch
BuildRequires:	pkgconfig(libcrypto)
%if %{without bootstrap}
BuildRequires:	cmake
BuildRequires:	pkgconfig(bzip2)
BuildRequires:	pkgconfig(expat)
BuildRequires:	gcc-gfortran
BuildRequires:	pkgconfig(libidn)
BuildRequires:	pkgconfig(jsoncpp)
BuildRequires:	pkgconfig(libarchive)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libuv)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	perl
BuildRequires:	xz
BuildRequires:	pkgconfig(zlib)
BuildRequires:	rhash-devel

%if %{with qt}
BuildRequires:	pkgconfig(Qt5Widgets)
%endif

%if %{with tests}
# Needed for test suite.
BuildRequires:	cxxtest
BuildRequires:	pkgconfig(Coin)
%endif

%endif

Requires:	rpm-mageia-setup
Requires:	%{name}-rpm-macros

Provides:	%{name}%{majorVersion} = %{version}-%{release}

%description
CMake is used to control the software compilation process using
simple platform and compiler independent configuration files.
CMake generates native makefiles and workspaces that can be
used in the compiler environment of your choice. CMake is quite
sophisticated: it is possible to support complex environments
requiring system configuration, pre-processor generation, code
generation, and template instantiation.

%files
%{_bindir}/cmake
%if ! %{with bootstrap}
%{_bindir}/ccmake
%endif
%{_bindir}/ctest
%{_bindir}/cpack
%{_datadir}/%{name}/
%{_datadir}/aclocal/cmake.m4
%{_datadir}/bash-completion/completions/*
%{_sysconfdir}/emacs/site-start.d/%{name}.el
%{_datadir}/vim/*/*
%{_datadir}/emacs/site-lisp/cmake-mode.el
%dir %{_libdir}/%{name}

#-----------------------------------------------------------------------------

%if %{without bootstrap}
%if %{with qt}
%package -n %{name}-qtgui
Summary:	Qt GUI Dialog for CMake - the Cross-platform, open-source make system
Group:		Development/Other
Requires:	%{name} = %{epoch}:%{version}-%{release}

%description -n %{name}-qtgui
CMake is used to control the software compilation process using
simple platform and compiler independent configuration files.

This is the Qt GUI.

%files -n %{name}-qtgui
%{_bindir}/cmake-gui
%{_datadir}/applications/cmake-gui.desktop
%{_datadir}/mime/packages/cmakecache.xml
%{_iconsdir}/*/*/*/*.png
%endif
%endif
#-----------------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}%{?prerel:-%prerel}
%autopatch -p1

# Don't try to automagically find files in /usr/X11R6
# But also don't change a prefix if it is not /usr
perl -pi -e 's@^\s+/usr/X11R6/.*\n@@' Modules/*.cmake

%ifarch %arm
# bootstrap test is taking ages on arm
sed -i -e 's!SET(CMAKE_LONG_TEST_TIMEOUT 1500)!SET(CMAKE_LONG_TEST_TIMEOUT 7200)!g' Tests/CMakeLists.txt
%endif

%build
%if %{with bootstrap}
mkdir -p %{_vpath_builddir}
cd %{_vpath_builddir}
%set_build_flags
../configure \
    --no-system-libs \
    --parallel="%_smp_mflags" \
    --prefix=%{_prefix} \
    --datadir=/share/%{name} \
    --mandir=/share/man \
    --docdir=/share/doc/%{name}
%make_build
%else
%cmake \
    -DCMAKE_USE_SYSTEM_LIBRARIES:BOOL=ON \
    -DCMAKE_DATA_DIR:PATH=/share/%{name} \
    -DCMAKE_MAN_DIR:PATH=/share/man \
    -DCMAKE_DOC_DIR:PATH=/share/doc/%{name} \
    -DBUILD_QtDialog:BOOL=%{?with_qt:ON}%{?!with_qt:OFF}
%cmake_build
%endif

%install
%make_install -C %{_vpath_builddir}

# cmake mode for emacs
install -d %{buildroot}%{_sysconfdir}/emacs/site-start.d
cat <<EOF >%{buildroot}%{_sysconfdir}/emacs/site-start.d/%{name}.el
(setq load-path (cons (expand-file-name "/dir/with/cmake-mode") load-path))
(require 'cmake-mode)
(setq auto-mode-alist
      (append '(("CMakeLists\\\\.txt\\\\'" . cmake-mode)
                ("\\\\.cmake\\\\'" . cmake-mode))
              auto-mode-alist))
EOF

# Create/Own this dir as this is used in cmake dependant rpms but not own by any
mkdir -p %{buildroot}%{_libdir}/%{name}

# There are some stray Copyright.txt files there sometimes.
rm -fr %{buildroot}%{_docdir}/%{name}/

%if %{with tests}
%check
unset DISPLAY
cd %{_vpath_builddir}
bin/ctest -V -E ModuleNotices -E 'CMake.(HTML|FileDownload)' -E CTestTestUpload %{?_smp_mflags}
%endif


%changelog
* Tue Dec 22 2020 wally <wally> 1:3.19.2-2.mga8
+ Revision: 1662880
- add patch to fix cmake builds with FindGTK2 and atkmm

* Thu Dec 17 2020 kekepower <kekepower> 1:3.19.2-1.mga8
+ Revision: 1660084
- Update to version 3.19.2

* Sun Nov 29 2020 luigiwalser <luigiwalser> 1:3.19.1-2.mga8
+ Revision: 1650313
- rebuild for jsoncpp

* Tue Nov 24 2020 kekepower <kekepower> 1:3.19.1-1.mga8
+ Revision: 1649071
- Update to version 3.19.1

* Fri Nov 20 2020 kekepower <kekepower> 1:3.19.0-1.mga8
+ Revision: 1648021
- Update to version 3.19.0

* Wed Nov 18 2020 kekepower <kekepower> 1:3.18.5-1.mga8
+ Revision: 1647275
- Update to version 3.18.5

* Tue Oct 06 2020 kekepower <kekepower> 1:3.18.4-1.mga8
+ Revision: 1632459
- Update to version 3.18.4

* Wed Sep 23 2020 kekepower <kekepower> 1:3.18.3-1.mga8
+ Revision: 1629480
- Update to version 3.18.3

* Thu Aug 20 2020 kekepower <kekepower> 1:3.18.2-1.mga8
+ Revision: 1617031
- Update to version 3.18.2

* Fri Jul 31 2020 kekepower <kekepower> 1:3.18.1-1.mga8
+ Revision: 1610032
- Update to version 3.18.1

* Fri Jul 17 2020 wally <wally> 1:3.18.0-1.mga8
+ Revision: 1606706
- new version 3.18.0

* Wed Jul 08 2020 wally <wally> 1:3.18.0-0.rc3.2.mga8
+ Revision: 1603046
- new version 3.18.0-rc3

* Thu Jun 11 2020 joequant <joequant> 1:3.17.3-2.mga8
+ Revision: 1592505
- run bootstrap

* Thu May 28 2020 kekepower <kekepower> 1:3.17.3-1.mga8
+ Revision: 1588662
- Update to version 3.17.3

* Wed Apr 29 2020 kekepower <kekepower> 1:3.17.2-1.mga8
+ Revision: 1573127
- Update to version 3.17.2

* Fri Apr 10 2020 kekepower <kekepower> 1:3.17.1-1.mga8
+ Revision: 1565936
- Update to version 3.17.1

* Mon Mar 30 2020 wally <wally> 1:3.17.0-2.mga8
+ Revision: 1562452
- split out cmake rpm macros and scripts into cmake-rpm-macros src pkg

* Fri Mar 20 2020 kekepower <kekepower> 1:3.17.0-1.mga8
+ Revision: 1558335
- Update to version 3.17.0 final

* Sun Mar 15 2020 kekepower <kekepower> 1:3.17.0-0.rc3.1.mga8
+ Revision: 1556544
- Update to version 3.17.0-rc3

* Wed Mar 04 2020 kekepower <kekepower> 1:3.17.0-0.rc2.1.mga8
+ Revision: 1553614
- Update to version 3.17.0-rc2

* Thu Feb 27 2020 wally <wally> 1:3.17.0-0.rc1.1.mga8
+ Revision: 1551064
- new version 3.17.0-rc1

* Thu Feb 20 2020 umeabot <umeabot> 1:3.16.4-2.mga8
+ Revision: 1547340
- Mageia 8 Mass Rebuild

* Fri Feb 07 2020 kekepower <kekepower> 1:3.16.4-1.mga8
+ Revision: 1487921
- Update to version 3.16.4

* Wed Jan 29 2020 daviddavid <daviddavid> 1:3.16.3-2.mga8
+ Revision: 1484899
- add missing epoch on qtgui subpkg

* Wed Jan 22 2020 kekepower <kekepower> 1:3.16.3-1.mga8
+ Revision: 1482046
- Update to version 3.16.3

* Thu Jan 02 2020 wally <wally> 1:3.16.2-3.mga8
+ Revision: 1475592
- don't do bootstrap build if not needed
- use symlinks for emacs and vim files
- replace deprecated %%setup_compile_flags
- replace %%setup_compile_flags with upstream %%set_build_flags in %%cmake macro

* Wed Dec 25 2019 wally <wally> 1:3.16.2-2.mga8
+ Revision: 1470062
- update cmake.prov shebang explicitly to python3
- update %%cmake macro to use %%_vpath_builddir and %%_vpath_srcdir
- introduce %%cmake_build and %%cmake_install macros

* Fri Dec 20 2019 kekepower <kekepower> 1:3.16.2-1.mga8
+ Revision: 1469067
- Update to version 3.16.2

* Fri Dec 13 2019 kekepower <kekepower> 1:3.16.1-1.mga8
+ Revision: 1466151
- Update to version 3.16.1

* Sun Dec 08 2019 wally <wally> 1:3.16.0-1.mga8
+ Revision: 1465173
- new version 3.16.0

* Thu Oct 03 2019 daviddavid <daviddavid> 1:3.15.4-1.mga8
+ Revision: 1448977
- new version: 3.15.4

* Thu Sep 05 2019 daviddavid <daviddavid> 1:3.15.3-1.mga8
+ Revision: 1437459
- new version: 3.15.3

* Fri Aug 30 2019 tv <tv> 1:3.15.2-2.mga8
+ Revision: 1435552
- no reason to use non standard /etc/rpm/macro.d

* Thu Aug 08 2019 kekepower <kekepower> 1:3.15.2-1.mga8
+ Revision: 1428234
- Update to version 3.15.2

* Sat Jul 27 2019 daviddavid <daviddavid> 1:3.15.1-2.mga8
+ Revision: 1424468
- rebuild for arm

* Fri Jul 26 2019 daviddavid <daviddavid> 1:3.15.1-1.mga8
+ Revision: 1424412
- new version 3.15.1

* Thu Jul 18 2019 wally <wally> 1:3.15.0-1.mga8
+ Revision: 1422549
- new version 3.15.0
- drop old conflicts
- clean cmake rpm macros a tiny bit
- don't set CMAKE_SKIP_RPATH to ON by default

* Fri Jul 12 2019 daviddavid <daviddavid> 1:3.15.0-0.rc4.1.mga8
+ Revision: 1420533
- new version 3.15.0 rc4

* Fri Jul 05 2019 wally <wally> 1:3.15.0-0.rc3.1.mga8
+ Revision: 1418809
- new version 3.15.0 rc3

* Mon Apr 22 2019 kekepower <kekepower> 1:3.14.3-1.mga7
+ Revision: 1394745
- Update to version 3.14.3

* Fri Apr 12 2019 kekepower <kekepower> 1:3.14.2-2.mga7
+ Revision: 1389476
- Bump rel

* Fri Apr 12 2019 kekepower <kekepower> 1:3.14.2-1.1.mga7
+ Revision: 1389466
- Update to version 3.14.2

* Sat Mar 30 2019 wally <wally> 1:3.14.1-1.mga7
+ Revision: 1381679
- new version 3.14.1

* Sat Mar 30 2019 umeabot <umeabot> 1:3.14.0-2.mga7
+ Revision: 1381442
- Qt5 Rebuild

* Wed Mar 20 2019 shlomif <shlomif> 1:3.14.0-1.mga7
+ Revision: 1379278
- New version 3.14.0

* Sat Mar 02 2019 wally <wally> 1:3.13.4-2.mga7
+ Revision: 1371039
- define runstatedir with cmake rpm macro

* Mon Feb 04 2019 kekepower <kekepower> 1:3.13.4-1.mga7
+ Revision: 1363179
- Update to version 3.13.4

* Tue Jan 15 2019 kekepower <kekepower> 1:3.13.3-1.mga7
+ Revision: 1357206
- Update to version 3.13.3

* Mon Jan 14 2019 wally <wally> 1:3.13.2-2.mga7
+ Revision: 1356839
- update cmake rpm macros
  - drop unused _cmake_disable_intree_build
  - add _cmake_builddir and _cmake_sourcedir (originally from suse)
  - add ctest macro (originally from suse)

* Thu Dec 13 2018 kekepower <kekepower> 1:3.13.2-1.mga7
+ Revision: 1341036
- Update to version 3.13.2

* Wed Nov 28 2018 kekepower <kekepower> 1:3.13.1-1.mga7
+ Revision: 1336557
- Update to version 3.13.1

* Wed Nov 21 2018 kekepower <kekepower> 1:3.13.0-2.mga7
+ Revision: 1332560
- fix release
- Update to version 3.13.0

* Fri Nov 02 2018 kekepower <kekepower> 1:3.12.4-1.mga7
+ Revision: 1327764
- Update to version 3.12.4

* Wed Oct 03 2018 kekepower <kekepower> 1:3.12.3-1.mga7
+ Revision: 1317275
- Update to version 3.12.3

* Sun Sep 23 2018 wally <wally> 1:3.12.2-1.mga7
+ Revision: 1297195
- new version 3.12.2

* Sat Sep 22 2018 umeabot <umeabot> 1:3.12.1-2.mga7
+ Revision: 1296617
- Mageia 7 Mass Rebuild

* Sun Aug 26 2018 wally <wally> 1:3.12.1-1.mga7
+ Revision: 1254782
- new version 3.12.1

* Sun Aug 05 2018 wally <wally> 1:3.12.0-1.mga7
+ Revision: 1247708
- new version 3.12.0

* Fri Jun 15 2018 kekepower <kekepower> 1:3.11.4-1.mga7
+ Revision: 1236954
- Update to version 3.11.4

* Sat May 19 2018 wally <wally> 1:3.11.2-1.mga7
+ Revision: 1230492
- new version 3.11.2

* Sun Apr 22 2018 kekepower <kekepower> 1:3.11.1-2.mga7
+ Revision: 1220887
- Bump rel to rebuild on arm

* Sun Apr 22 2018 kekepower <kekepower> 1:3.11.1-1.mga7
+ Revision: 1220882
- Update to version 3.11.1

* Sun Apr 15 2018 wally <wally> 1:3.11.0-1.mga7
+ Revision: 1218953
- new version 3.11.0

* Fri Mar 23 2018 wally <wally> 1:3.11.0-0.rc4.1.mga7
+ Revision: 1211614
- new version 3.11.0-rc4

* Tue Feb 27 2018 neoclust <neoclust> 1:3.11.0-0.rc2.2.mga7
+ Revision: 1205589
- Rebuild with fixed BS
- New version 3.11.0 Rc2

* Mon Jan 29 2018 kekepower <kekepower> 1:3.10.2-1.mga7
+ Revision: 1197997
- Update to version 3.10.2
- Added an upstream patch to detect Boost 1.66.0

* Mon Jan 01 2018 wally <wally> 1:3.10.1-1.mga7
+ Revision: 1188832
- new version 3.10.1

* Sat Dec 09 2017 wally <wally> 1:3.10.0-1.mga7
+ Revision: 1181814
- new version 3.10.0

* Thu Nov 02 2017 neoclust <neoclust> 1:3.10.0-0.rc4.1.mga7
+ Revision: 1175470
- New version 3.10.0-rc4

* Sun Oct 22 2017 wally <wally> 1:3.10.0-0.rc3.1.mga7
+ Revision: 1173044
- new version 3.10.0 rc3

* Thu Oct 19 2017 mjack <mjack> 1:3.10.0-0.rc2.1.mga7
+ Revision: 1172697
- Updated to version 3.10.0 rc2

* Fri Oct 13 2017 eatdirt <eatdirt> 1:3.9.3-2.mga7
+ Revision: 1171523
- Rebuild for new jsoncpp

* Sun Oct 01 2017 wally <wally> 1:3.9.3-1.mga7
+ Revision: 1162104
- new version 3.9.3

* Fri Jul 21 2017 wally <wally> 1:3.9.0-1.mga7
+ Revision: 1125853
- new version 3.9.0

* Mon Jul 17 2017 neoclust <neoclust> 1:3.9.0-0.rc6.1.mga7
+ Revision: 1124502
- New version 3.9.0 RC6

* Fri Jun 09 2017 akien <akien> 1:3.7.2-3.mga6
+ Revision: 1107391
- Provide cmake3 to reduce diff with Fedora packaging

* Wed Jan 18 2017 wally <wally> 1:3.7.2-2.mga6
+ Revision: 1082329
- drop old enable_debug macro definitions from %%cmake macro

* Tue Jan 17 2017 wally <wally> 1:3.7.2-1.mga6
+ Revision: 1082162
- new version 3.7.2

* Mon Jan 02 2017 akien <akien> 1:3.7.1-2.mga6
+ Revision: 1079574
- Rebuild for libjsoncpp changed soname

* Sun Jan 01 2017 wally <wally> 1:3.7.1-1.mga6
+ Revision: 1079111
- new version 3.7.1
- BR libuv-devel

* Fri Dec 30 2016 wally <wally> 1:3.5.2-5.mga6
+ Revision: 1078690
- add %%_cmake_disable_intree_build macro and enable it by default for now (so we can later, maybe for mga7, disable it and do intree builds by default)

* Fri Dec 30 2016 wally <wally> 1:3.5.2-4.mga6
+ Revision: 1078662
- move non rpm related files to main pkg from cmake-rpm-macros

* Fri May 06 2016 neoclust <neoclust> 1:3.5.2-3.mga6
+ Revision: 1009750
- Split rpm macros / autoprov out of cmake main rpm

* Wed Apr 20 2016 daviddavid <daviddavid> 1:3.5.2-2.mga6
+ Revision: 1003695
- rebuild for arm due to an invalid build error

* Tue Apr 19 2016 daviddavid <daviddavid> 1:3.5.2-1.mga6
+ Revision: 1003612
- new version: 3.5.2

* Fri Mar 25 2016 neoclust <neoclust> 1:3.5.1-1.mga6
+ Revision: 995475
- New version 3.5.1

* Sat Mar 19 2016 wally <wally> 1:3.5.0-1.mga6
+ Revision: 992915
- new version 3.5.0
- drop unneeded Fix-FLTK-Find-path.patch

* Wed Jan 20 2016 wally <wally> 1:3.4.2-1.mga6
+ Revision: 926122
- new version 3.4.2

* Sun Jan 03 2016 wally <wally> 1:3.4.1-9.mga6
+ Revision: 919054
- remove '-O2 -g' (and only keep -DNDEBUG) from RELWITHDEBINFO flags, since this is already in our C[XX]FLAGS and would prevent overriding them (originally from blino)
- create %%_cmake_module_linker_flags rpm macro for the default CMAKE_MODULE_LINKER_FLAGS flags
- create %%_cmake_module_linker_flags_extra rpm macro for additional flags besides the default flags

* Sun Dec 27 2015 neoclust <neoclust> 1:3.4.1-8.mga6
+ Revision: 916150
- Add prov file back in cmake

* Sun Dec 27 2015 wally <wally> 1:3.4.1-7.mga6
+ Revision: 916026
- move cmake.prov and cmake.attr to rpm-mageia-setup-build

* Sun Dec 27 2015 wally <wally> 1:3.4.1-6.mga6
+ Revision: 915905
- find cmake() provides also from /usr/share/cmake/

* Sun Dec 27 2015 neoclust <neoclust> 1:3.4.1-5.mga6
+ Revision: 915855
- Use python2 for cmake() provides script as python3 is not in the chroot (wally)

* Sun Dec 27 2015 neoclust <neoclust> 1:3.4.1-4.mga6
+ Revision: 915728
- Add back skip rpath

* Sat Dec 26 2015 neoclust <neoclust> 1:3.4.1-3.mga6
+ Revision: 915116
- Rebuild with install fix
- Add cmake rpm auto-provide file
- Remove -DCMAKE_SKIP_RPATH:BOOL=ON from %%cmake macro

* Tue Dec 08 2015 wally <wally> 1:3.4.1-1.mga6
+ Revision: 908890
- new version 3.4.1
- pass -DCMAKE_VERBOSE_MAKEFILE:BOOL=ON by default to %%cmake macro

* Fri Nov 13 2015 neoclust <neoclust> 1:3.4.0-1.mga6
+ Revision: 903053
- New version 3.4.0

* Sun Nov 08 2015 wally <wally> 1:3.4.0-0.rc3.1.mga6
+ Revision: 898684
- new version 3.4.0 rc3

* Fri Oct 23 2015 wally <wally> 1:3.4.0-0.rc2.1.mga6
+ Revision: 894479
- new version 3.4.0 rc2

* Fri Oct 09 2015 wally <wally> 1:3.4.0-0.rc1.1.mga6
+ Revision: 888221
- new version 3.4.0 rc1
- force building packages with debug symbols (set the build type to RelWithDebInfo instead of Release with %%cmake macro)

* Fri Sep 18 2015 fwang <fwang> 1:3.3.2-1.mga6
+ Revision: 880303
- 3.3.2

* Fri Sep 11 2015 blino <blino> 1:3.3.1-5.mga6
+ Revision: 878311
- build qtgui with Qt5 instead of Qt4

* Wed Aug 26 2015 fwang <fwang> 1:3.3.1-4.mga6
+ Revision: 869529
- update url

* Thu Aug 13 2015 neoclust <neoclust> 1:3.3.1-3.mga6
+ Revision: 864547
- New version 3.3.1

* Wed Aug 12 2015 shlomif <shlomif> 1:3.3.0-3.mga6
+ Revision: 863463
- Rebuild for the new jsoncpp.
+ neoclust <neoclust>
- Rebuild against new jsoncpp-devel

* Mon Jul 27 2015 neoclust <neoclust> 1:3.3.0-1.mga6
+ Revision: 858221
- New version 3.3.0
- New version 3.3.0

* Wed Oct 15 2014 umeabot <umeabot> 1:3.0.1-5.mga5
+ Revision: 743426
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1:3.0.1-4.mga5
+ Revision: 678449
- Mageia 5 Mass Rebuild

* Tue Aug 05 2014 neoclust <neoclust> 1:3.0.1-3.mga5
+ Revision: 659758
- Rebuild with file list fixed
- Add emacs support
- Add bash completion support
- Add vim config files
- New version 3.0.1

* Thu Apr 17 2014 wally <wally> 1:2.8.12.2-3.mga5
+ Revision: 615467
- define CMAKE_INSTALL_SYSCONFDIR in %%cmake macro

* Sat Feb 08 2014 fwang <fwang> 1:2.8.12.2-2.mga5
+ Revision: 586283
- recognize freetype 2.5

* Wed Feb 05 2014 fwang <fwang> 1:2.8.12.2-1.mga5
+ Revision: 583186
- new version 2.8.12.2

* Thu Nov 07 2013 blino <blino> 1:2.8.12.1-1.mga4
+ Revision: 549884
- 2.8.12.1

* Mon Oct 21 2013 umeabot <umeabot> 1:2.8.12-2.mga4
+ Revision: 541066
- Mageia 4 Mass Rebuild

* Fri Oct 11 2013 fwang <fwang> 1:2.8.12-1.mga4
+ Revision: 495028
- new version 2.8.12

* Thu Jul 04 2013 fwang <fwang> 1:2.8.11.2-1.mga4
+ Revision: 450031
- new version 2.8.11.2

* Fri Jun 28 2013 fwang <fwang> 1:2.8.11.1-2.mga4
+ Revision: 447739
- rebuild for new libarchive

* Mon Jun 10 2013 kamil <kamil> 1:2.8.11.1-1.mga4
+ Revision: 441870
- new version 2.8.11.1

* Mon Jun 03 2013 kamil <kamil> 1:2.8.11-3.mga4
+ Revision: 435580
- install bash-completion files: cmake, cpack, ctest

* Tue May 28 2013 fwang <fwang> 1:2.8.11-2.mga4
+ Revision: 429227
- detect new imagemaigck include dir

* Sun May 26 2013 neoclust <neoclust> 1:2.8.11-1.mga4
+ Revision: 428273
- New version 2.8.11

* Fri Jan 11 2013 umeabot <umeabot> 1:2.8.10.2-5.mga3
+ Revision: 347950
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 06 2013 mitya <mitya> 1:2.8.10.2-4.mga3
+ Revision: 339729
- Provide LIBEXECDIR=%%{_libexecdir}

* Fri Dec 28 2012 mitya <mitya> 1:2.8.10.2-3.mga3
+ Revision: 335780
- Provide LIBEXECDIR=%%{_libdir}

* Mon Dec 17 2012 pterjan <pterjan> 1:2.8.10.2-2.mga3
+ Revision: 331959
- Support spaces in _smp_mflags

* Wed Nov 28 2012 fwang <fwang> 1:2.8.10.2-1.mga3
+ Revision: 322558
- new version 2.8.10.2

* Tue Nov 06 2012 mikala <mikala> 1:2.8.10-1.mga3
+ Revision: 314715
- Update tarball to final 2.8.10

* Sat Oct 27 2012 neoclust <neoclust> 1:2.8.10-0.rc3.1.mga3
+ Revision: 310598
- New version 2.9.10 rc3

* Sat Aug 11 2012 neoclust <neoclust> 1:2.8.9-1.mga3
+ Revision: 280564
- New version 2.8.9 Final

* Thu Aug 09 2012 neoclust <neoclust> 1:2.8.9-0.rc3.1.mga3
+ Revision: 280075
- New version 2.8.9-rc3

* Fri Jun 08 2012 fwang <fwang> 1:2.8.8-1.mga3
+ Revision: 257642
- new version 2.8.8

* Sun Feb 26 2012 shlomif <shlomif> 1:2.8.7-5.mga2
+ Revision: 215381
- Updated cmake-2.8.4-xz patch from the Mandriva repository. Applying it again.

* Mon Jan 23 2012 dmorgan <dmorgan> 1:2.8.7-4.mga2
+ Revision: 200174
- Own %%_libdir/%%name

* Tue Jan 17 2012 mikala <mikala> 1:2.8.7-3.mga2
+ Revision: 197113
- Remove ugly patch done by me to restore boost detection (the error was in boost packaging)

* Wed Jan 04 2012 fwang <fwang> 1:2.8.7-2.mga2
+ Revision: 190635
- rebuild for new libarchive

* Sat Dec 31 2011 fwang <fwang> 1:2.8.7-1.mga2
+ Revision: 189268
- new version 2.8.7

* Sun Oct 09 2011 fwang <fwang> 1:2.8.6-1.mga2
+ Revision: 153428
- new version 2.8.6

* Wed Sep 28 2011 fwang <fwang> 1:2.8.6-0.rc4.1.mga2
+ Revision: 149962
- new version 2.8.6 rc4

* Wed Sep 14 2011 fwang <fwang> 1:2.8.6-0.rc3.2.mga2
+ Revision: 143569
- fix pthread detection

* Sat Sep 10 2011 fwang <fwang> 1:2.8.6-0.rc3.1.mga2
+ Revision: 142167
- new version 2.8.6 rc3

* Thu Sep 08 2011 mikala <mikala> 1:2.8.6-0.rc2.2.mga2
+ Revision: 140979
- Add patch3 to reverse for the moment a change regarding FindBoost.cmake module (which prevent findings boost librairies)

* Wed Sep 07 2011 dmorgan <dmorgan> 1:2.8.6-0.rc2.1.mga2
+ Revision: 140712
- Remove file moving, the files does not exist anymore
- New version 2.8.6 rc2
- New version 2.8.6-rc1
+ tv <tv>
- fix %%install
- fix file list

* Sat Jul 09 2011 ahmad <ahmad> 1:2.8.5-1.mga2
+ Revision: 120929
- Update to 2.8.5

* Thu Jul 07 2011 ahmad <ahmad> 1:2.8.5-0.rc3.1.mga2
+ Revision: 119742
- Update to 2.8.5-rc3
- Change the spec to make it easier to package rc's
+ kharec <kharec>
- just clean the top of spec by tabs, no need to increment rel.

* Tue Mar 15 2011 ahmad <ahmad> 1:2.8.4-1.mga1
+ Revision: 72094
- update to 2.8.4

* Fri Feb 11 2011 ahmad <ahmad> 1:2.8.3-4.mga1
+ Revision: 49945
- drop py27 patch, fixed upstream
- use current qt4 Epoch in the qt4-devel BR
- remove the mydocs hack, %%doc macro was fixed ages ago

* Sun Jan 16 2011 dmorgan <dmorgan> 1:2.8.3-3.mga1
+ Revision: 20018
- Rebuild with new cmake

* Fri Jan 14 2011 dmorgan <dmorgan> 1:2.8.3-2.mga1
+ Revision: 17381
- Bump release
- Rebuild cmake with qt4 support now

* Tue Jan 11 2011 dmorgan <dmorgan> 1:2.8.3-1.mga1
+ Revision: 6287
- Do not build qtgui for now
+ ahmad <ahmad>
- drop old scriptlets and conflicts
- require rpm-magei-setup
- imported package cmake


* Thu Nov 11 2010 Funda Wang <fwang@mandriva.org> 1:2.8.3-1mdv2011.0
+ Revision: 595932
- new version 2.8.3 final

* Mon Nov 01 2010 Funda Wang <fwang@mandriva.org> 1:2.8.3-0.rc4.1mdv2011.0
+ Revision: 591548
- disable subdir test
- add BRs
- new version 2.8.3 rc4
- disable xz patch for now (does not apply with current api)
- recognize py 2.7

* Tue Jul 27 2010 Funda Wang <fwang@mandriva.org> 1:2.8.2-1mdv2011.0
+ Revision: 560902
- New version 2.8.2

* Sun Mar 21 2010 Funda Wang <fwang@mandriva.org> 1:2.8.1-1mdv2010.1
+ Revision: 525975
- fix xz patch
- update file list
- New version 2.8.1

  + Nicolas Lécureuil <nlecureuil@mandriva.com>
    - Add a warning about the use of -DCMAKE_MODULE_LINKER_FLAGS for kde qt apps

* Sat Nov 14 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-9mdv2010.1
+ Revision: 465942
- 2.8.0 final

* Fri Nov 13 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-8mdv2010.1
+ Revision: 465799
- new version 2.8.0 rc7

* Wed Nov 11 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-7mdv2010.1
+ Revision: 464481
- 2.8 rc6

* Wed Nov 04 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-6mdv2010.1
+ Revision: 460415
- 2.8 rc5
- New version 2.8.0 rc4

* Sat Oct 10 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-5mdv2010.0
+ Revision: 456524
- 2.8 rc3
- vtk patch not neede since cmake search for vtk's own cmake module

* Wed Oct 07 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.8.0-4mdv2010.0
+ Revision: 455780
- rebuild for new curl SSL backend

* Tue Oct 06 2009 Thierry Vignaud <tv@mandriva.org> 1:2.8.0-3mdv2010.0
+ Revision: 454727
- do not package huge ChangeLog

* Sat Oct 03 2009 Funda Wang <fwang@mandriva.org> 1:2.8.0-2mdv2010.0
+ Revision: 452812
- do not check license of xz patch
- add BSD license to xz patch (aquired by peroyvind)
- 2.8 rc2

* Mon Sep 28 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.8.0-1mdv2010.0
+ Revision: 450565
- New code doesn't have requires on libxml-c-rpc
- New upstream version release candidate 1

* Fri Sep 25 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.4-7mdv2010.0
+ Revision: 449016
- Make release as default in cmake macros

* Fri Sep 25 2009 Olivier Blin <oblin@mandriva.com> 1:2.6.4-4mdv2010.0
+ Revision: 448833
- increase timeout for long test on arm, tests 89 (bootstrap) is
  taking a lot of time (from Arnaud Patard)
- introduce a bootstrap option to break loop build dep,
  cups->htmldoc->fltk->cmake->qt4->cups (from Arnaud Patard)

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - * fix broken macro messing with rpath making it unable to active due to
      redefinition, rpath should be OFF (skipped) by default, but also possible
      to override to enable

* Fri May 01 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:2.6.4-3mdv2010.0
+ Revision: 369195
- Build with debug

* Thu Apr 30 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.4-2mdv2010.0
+ Revision: 369165
- Add back cooker debug by default

  + Nicolas Lécureuil <nlecureuil@mandriva.com>
    - New version

* Tue Mar 31 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.3-4mdv2009.1
+ Revision: 363092
- Debug switch is only alocated on cmake macros now. To enable debug a
  _enable_debug 1 should be passed to package build
- Use same debug conditional style like kde4

* Fri Feb 27 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.3-2mdv2009.1
+ Revision: 345543
- Small adjust for old distros

* Mon Feb 23 2009 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:2.6.3-1mdv2009.1
+ Revision: 344267
- Update to final version

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - add gcc-gfortran to buildrequires since it's required by the test suite
    - make cmake datadir unversioned so that other software may install their .cmake
      files to a standard location where they can be made use of

* Thu Feb 19 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.3-0.RC13.2mdv2009.1
+ Revision: 342768
- People insist that VERBOSE should be on by default. Guess what ? Will not
  happens.

* Thu Feb 12 2009 Funda Wang <fwang@mandriva.org> 1:2.6.3-0.RC13.1mdv2009.1
+ Revision: 339709
- 2.6.3 RC 13

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - make verbosive build into a macro which can be override, thus making it optional
    - fix typo

* Tue Jan 27 2009 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.3-0.RC8.3mdv2009.1
+ Revision: 334143
- People are going too far and not letting anyone happy with such decisions.

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - revert previous patch as the info message printed next to the progress bar
      actually is colored..
    - make progress indicator colored to make it more clear, especially with several
      build jobs in parallel (P3, hopefully makes Colin happy?:)
    - don't blindly modify all files for lib64, cmake files are lib64 aware already
    - make cmake.macros more in sync with fedora to make it easier to maintain
    - drop chrpath buildrequires since it's chrpath isn't even used during build
    - make build verbose
    - build cmake in a separate build dir rather than in the source dir
    - fix docs so that we don't ship more than we want and don't breaking short
      circuiting
    - minor spec cosmetics..
    - don't add rpaths to linked libraries
    - add -DCMAKE_VERBOSE_MAKEFILE:BOOL=ON to %%cmake macro to print build output by
      default

* Thu Jan 22 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 1:2.6.3-0.RC8.2mdv2009.1
+ Revision: 332397
- add support for tar.xz (TXZ) generator and cmake file for liblzma (P2)

  + Helio Chissini de Castro <helio@mandriva.com>
    - Provide vim files now, instead of obsolete one from vim package.
    - Use system libs instead of internal sources
    - Added ultiporc compilation since bootstrap

* Wed Jan 14 2009 Funda Wang <fwang@mandriva.org> 1:2.6.3-0.RC8.1mdv2009.1
+ Revision: 329494
- make test in check section
- 2.6.3 RC 8
- define CMAKE_MODULE_LINKER_FLAGS so that linking modules won't fail

* Fri Dec 12 2008 Funda Wang <fwang@mandriva.org> 1:2.6.3-0.RC5.3mdv2009.1
+ Revision: 313576
- BR idn

* Fri Dec 12 2008 Funda Wang <fwang@mandriva.org> 1:2.6.3-0.RC5.2mdv2009.1
+ Revision: 313567
- use compile flags

* Thu Dec 11 2008 Nicolas Lécureuil <nlecureuil@mandriva.com> 1:2.6.3-0.RC5.1mdv2009.1
+ Revision: 312871
- New version 2.6.3 RC 5
- Add cmake Qtgui

* Sun Oct 12 2008 Funda Wang <fwang@mandriva.org> 1:2.6.2-1mdv2009.1
+ Revision: 292807
- New version 2.6.2

* Thu Aug 21 2008 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.1-1mdv2009.0
+ Revision: 274618
- New upstream version

* Wed Aug 06 2008 Thierry Vignaud <tv@mandriva.org> 1:2.6.0-4mdv2009.0
+ Revision: 264356
- rebuild early 2009.0 package (before pixel changes)

* Fri Jun 06 2008 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.0-3mdv2009.0
+ Revision: 216531
- Implement new cmake macro to accomplish first part of bug https://qa.mandriva.com/show_bug.cgi?id=41284 ( new flags )

* Fri May 30 2008 Paulo Andrade <pcpa@mandriva.com.br> 1:2.6.0-2mdv2009.0
+ Revision: 213502
- Don't try to automagically find files in /usr/X11R6.
  But also don't change a prefix if it is not /usr.

  + Funda Wang <fwang@mandriva.org>
    - fix url

* Wed May 07 2008 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.0-1mdv2009.0
+ Revision: 202676
- Upstream 2.6.0 final release

* Wed Apr 30 2008 Helio Chissini de Castro <helio@mandriva.com> 1:2.6.0-0.1.rc9mdv2009.0
+ Revision: 199613
- Start to use new cmake 2.6 in release candidate 9. Better do early adopt now.

* Fri Feb 08 2008 Helio Chissini de Castro <helio@mandriva.com> 1:2.4.8-1mdv2008.1
+ Revision: 164160
- Reverting cmake for stable 2.4.8. KDE 4 assume > 2.4.5 and going to devel version is leading to some unexpected path bad behavior.
- Patches from expat and wx was backported

* Wed Feb 06 2008 Helio Chissini de Castro <helio@mandriva.com> 2.5.0-0.20080106.1mdv2008.1
+ Revision: 163028
- Update to more recent CVS snapshot
- Removed already applied upstream expat and wx patches

* Wed Jan 30 2008 Giuseppe Ghibò <ghibo@mandriva.com> 2.5.0-0.20071024.3mdv2008.1
+ Revision: 160292
- Fix expat detection (bug CMake#6062).

* Tue Jan 08 2008 Olivier Blin <oblin@mandriva.com> 2.5.0-0.20071024.2mdv2008.1
+ Revision: 146562
- fix wx-config output being flattened
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Wed Oct 24 2007 Nicolas Lécureuil <nlecureuil@mandriva.com> 2.5.0-0.20071024.1mdv2008.1
+ Revision: 101840
- Update to cvs snapshot (because kde4 needs it)

  + Thierry Vignaud <tv@mandriva.org>
    - replace %%_datadir/man by %%_mandir!

* Thu Jul 19 2007 Funda Wang <fwang@mandriva.org> 2.4.7-1mdv2008.0
+ Revision: 53410
- New version

  + Helio Chissini de Castro <helio@mandriva.com>
    - Add rpm macros for cmake. Thanks to Anssi Hannula for point this ones.


* Tue Jan 23 2007 Gustavo De Nardin <gustavodn@mandriva.com> 2.4.6-2mdv2007.0
+ Revision: 112566
- don't double package some documentation files
- install emacs mode

* Fri Jan 12 2007 Laurent Montel <lmontel@mandriva.com> 2.4.6-1mdv2007.1
+ Revision: 107768
- 2.4.6

* Tue Jan 09 2007 Laurent Montel <lmontel@mandriva.com> 2.4.6-0.rc2.1mdv2007.1
+ Revision: 106621
- 2.4.6-rc2

* Tue Dec 05 2006 Laurent Montel <lmontel@mandriva.com> 2.4.5-1mdv2007.1
+ Revision: 90681
- 2.4.5

* Tue Nov 21 2006 Laurent Montel <lmontel@mandriva.com> 2.4.4-1mdv2007.1
+ Revision: 85881
- 2.4.4

  + Gaëtan Lehmann <glehmann@mandriva.org>
    - fix fltk detection (patch 1)

* Wed Aug 02 2006 Laurent Montel <lmontel@mandriva.com> 2.4.3-2mdv2007.0
+ Revision: 42884
- New release 2.4.3 (2006/08/01)
- 2.4.3
- 2.4.2

  + Andreas Hasenack <andreas@mandriva.com>
    - renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

  + Gaëtan Lehmann <glehmann@mandriva.org>
    - update release tag
    - fix vtk 5.0 detection

  + Helio Chissini de Castro <helio@mandriva.com>
    - Added the current source
    - New Cmake 2.4.1 beta. Required for current KDE 4 development
    - Added cmake on subversion. Gaetan, current maintainer was already notified and now, since kde 4 move development pro cmake and Laurent, me and Boiko will need cmake up to date

* Sat Mar 25 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060321.2mdk
- lib -> lib64 on x86_64 - the fix in cmake is not enough

* Tue Mar 21 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060321.1mdk
- 2.3.4 (snapshot 20060321)

* Wed Mar 15 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060315.2mdk
- build requires

* Wed Mar 15 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.4-0.20060315.1mdk
- 2.3.4 (snapshot 20060315)

* Sun Mar 12 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060312.1mdk
- 2.3.4 (snapshot 20060312)

* Sun Feb 12 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.3
- 2.3.3 (snapshot 20060210)

* Fri Feb 10 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.2
- 2.3.2 version (snapshot 20060209)

* Fri Feb 03 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.3-3mdk
- fix kde search path

* Sun Jan 22 2006 Laurent MONTEL <lmontel@mandriva.com> 2.2.3-2mdk
- Fix spec file. I don't understand how a 2.2.2 spec file was integrate into 2.2.3 package (nobody couldn't rebuild it)

* Fri Nov 04 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.2-1mdk
- New release 2.2.2

* Thu Oct 20 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.1-1mdk
- New release 2.2.1

* Tue Jul 19 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.0-1mdk
- 2.2.0
- make it more rpmbuildupdatable
- buildrequires ncurses-devel
- list files in bindir to be sure that ccmake is built

* Fri Jun 10 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-3mdk
- also fix X11 lib path on x86_64

* Fri Jun 10 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-2mdk
- fix lib path to make ccmake compile on x86_64. It should also help
  to find lib with this arch

* Wed Apr 27 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-1mdk
- New release 2.0.6
- use mkrel

* Fri Mar 11 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.5-2mdk
- fix some lint
- add examples in docs

* Tue Nov 23 2004 Gaetan LEHMANN <gaetan.lehmann@jouy.inra.fr> 2.0.5-1mdk
- 2.0.5

* Wed Jun 16 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 1.6.7-2mdk
- Rebuild

